#!/usr/bin/python 
#
# ESA (C) 2000-2021 
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.



import pysas.pyutils.pyutils as pyutils
import pytest
import os
import numpy as np


def test_get_key_word():
    instr = pyutils.get_key_word('example.fits', 'INSTRUME')
    assert instr == 'OM'


def test_pydump():
    values = pyutils.pydump('example.fits', 1, 'FRAME')
    assert len(values) == 100


def test_is_notebook():
    pyutils.is_notebook()
    assert True # cannot do further testing due to dependancy of environment


def test_create_file_from_data():
    a = np.arange(20)
    b = np.arange(20) * 3
    pyutils.create_fits_from_data((a, b), ('a', 'b'), 'outtest')
    if os.path.isfile('outtest.fits'):
        os.remove('outtest.fits')
        assert True
    else:
        assert False


def test_merge_fits():
    status = pyutils.merge_fits(['merge1.fits', 'merge2.fits'], ['SPECTRUM'], 'output_merge.fits', ('CHANNEL', 'RATE'), new_ext = 'merged')
    if status:
        os.remove('output_merge.fits')
        assert True
    else:
        assert False

    
def test_imgstat():
    pyutils.imgstat('test_image.fits', 0, 2000, 'test_imgstat.txt')
    if os.path.isfile('test_imgstat.txt'):
        os.remove('test_imgstat.txt')
        assert True
